function [xt, Rx, yp] = Kalman(xt, yt, ut, M, N, A, B, Rw, Rv, Rx)
  % [xt, Rx, yp] = Kalman(xt, yt, ut, M, N, A, B, Rw, Rv, Rx)
  % Kalmanův filtr pro odhad stavu s modelem
  %                             xt = M * xt + N * ut + w
  %                             yp = A * xt + B * ut + e
  % xt    stav
  % Rx    kovarianční matice odhadu stavu
  % yp    předpověď výstupu
  % yt    výstup
  % ut    vstup
  % M,N   parametry stavového modelu
  % A,B   parametry výstupního modelu
  % Rw    kovariance stavového modelu
  % Rv    kovariance výstupního modelu

  % Predikce
  xt = M * xt + N * ut;                % časová aktualizace stavu
  Rx = Rw + M * Rx * M';               % časová aktualizace kovariance stavu

  % Filtrace
  yp = A * xt + B * ut;                % předpověď výstupu
  Ry = Rv + A * Rx * A';               % aktualizace kovariance šumu
  Rx = Rx - Rx * A' / Ry * A * Rx;     % aktualizace kovariance odhadu stavu
  ey = yt - yp;                        % chyba předpovědi
  KG = Rx * A' / Rv;                   % Kalmanův zisk
  xt = xt + KG * ey;                   % datová aktualizace střední hodnoty stavu
end
